@@ -32,7 +32,7 @@ The list of supported arguments are as follows:
 |                     | a usable state.                                       |
 +---------------------+-------------------------------------------------------+
 | ``polymorphic``     | Whether the inheritance should be polymorphic or not. |
-|                     | Defaults to ``False``.                                |
+|                     | Defaults to ``True``.                                 |
 +---------------------+-------------------------------------------------------+
 | ``metadata``        | Specify a custom MetaData for this entity.            |
 |                     | By default, entities uses the global                  |
@@ -95,7 +95,7 @@ The list of supported arguments are as follows:
 |                     | condition happen: some of its attributes are accessed |
 |                     | ('c', 'table', 'mapper' or 'query'), instanciated     |
 |                     | (called) or the create_all method of this entity's    |
-|                     | metadata is called. Defaults to ``True``.             |
+|                     | metadata is called. Defaults to ``False``.            |
 +---------------------+-------------------------------------------------------+
 | ``allowcoloverride``| Specify whether it is allowed to override columns.    |
 |                     | By default, Elixir forbids you to add a column to an  |
@@ -140,13 +140,28 @@ function's documentation
 '''
 
 from elixir.statements import ClassMutator
+from sqlalchemy import Integer, String
 
 __doc_all__ = ['options_defaults']
 
+# format constants
+FKCOL_NAMEFORMAT = "%(relname)s_%(key)s"
+M2MCOL_NAMEFORMAT = "%(tablename)s_%(key)s"
+CONSTRAINT_NAMEFORMAT = "%(tablename)s_%(colnames)s_fk"
+
+# other global constants
+DEFAULT_AUTO_PRIMARYKEY_NAME = "id"
+DEFAULT_AUTO_PRIMARYKEY_TYPE = Integer
+DEFAULT_VERSION_ID_COL_NAME = "row_version"
+DEFAULT_POLYMORPHIC_COL_NAME = "row_type"
+POLYMORPHIC_COL_SIZE = 40
+POLYMORPHIC_COL_TYPE = String(POLYMORPHIC_COL_SIZE)
+
+# 
 options_defaults = dict(
-    autosetup=True,
+    autosetup=False,
     inheritance='single',
-    polymorphic=False,
+    polymorphic=True,
     autoload=False,
     tablename=None,
     shortnames=False,
@@ -157,6 +172,7 @@ options_defaults = dict(
     table_options=dict(),
 )
 
+
 valid_options = options_defaults.keys() + [
     'metadata',
     'session',
@@ -164,6 +180,7 @@ valid_options = options_defaults.keys() + [
     'order_by',
 ]
 
+
 def using_options_handler(entity, *args, **kwargs):
     for kwarg in kwargs:
         if kwarg in valid_options:
